#
# spec file for package ghc-atomic-primops
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name atomic-primops
Name:           ghc-%{pkg_name}
Version:        0.8.0.4
Release:        1.11
Summary:        A safe approach to CAS and other atomic ops in Haskell
License:        BSD-3-Clause
Group:          System/Libraries
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
# Begin cabal-rpm deps:
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# End cabal-rpm deps
BuildRequires:  ghc-template-haskell-devel

%description
After GHC 7.4 a new `casMutVar#` primop became available, but it's difficult to
use safely, because pointer equality is a highly unstable property in Haskell.
This library provides a safer method based on the concept of "Tickets".

Also, this library uses the "foreign primop" capability of GHC to add access to
other variants that may be of interest, specifically, compare and swap inside
an array.

Note that as of GHC 7.8, the relevant primops have been included in GHC itself.
This library is engineered to work pre- and post-GHC-7.8, while exposing the
same interface.

Changes in 0.3:

* Major internal change. Duplicate the barrier code from the GHC RTS and thus
enable support for executables that are NOT built with '-threaded'.

Changes in 0.4:

* Further internal changes, duplicate 'cas' routine well as barriers.

* Add `fetchAddByteArrayInt`

* Add an `Unboxed` counter variant that uses movable "ByteArray"s on the GHC
heap.

Changes in 0.5:

* Remove dependency on bits-atomic unless a flag is turned on.

Changes in 0.5.0.2:

* IMPORTANT BUGFIXES - don't use earlier versions. They have been marked
deprecated.

Changes in 0.6.1

* This is a good version to use for GHC 7.8.3. It includes portability and bug
fixes and adds atomicModifyIORefCAS.

Changes in 0.7:

* This release adds support for GHC 7.10 and its expanded library of (now
inline) primops.

Changes in 0.8:

* Implements additional fetch primops available in GHC 7.10

Changes in 0.8.0.4:

* Internal changes to support forthcoming GHC 8.0.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}


%build
%ghc_lib_build


%install
%ghc_lib_install


%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)

%changelog
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.8.0.4 revision 0 with cabal2obs.
